Stan Math Library: stan/math/prim/scal/fun.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

fun.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_HPP
3
4 #include <stan/math/prim/scal/fun/abs.hpp>
5 #include <stan/math/prim/scal/fun/as_bool.hpp>
6 #include <stan/math/prim/scal/fun/bessel_first_kind.hpp>
7 #include <stan/math/prim/scal/fun/bessel_second_kind.hpp>
8 #include <stan/math/prim/scal/fun/binary_log_loss.hpp>
9 #include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>
10 #include <stan/math/prim/scal/fun/constants.hpp>
11 #include <stan/math/prim/scal/fun/corr_constrain.hpp>
12 #include <stan/math/prim/scal/fun/corr_free.hpp>
13 #include <stan/math/prim/scal/fun/digamma.hpp>
14 #include <stan/math/prim/scal/fun/divide.hpp>
15 #include <stan/math/prim/scal/fun/exp2.hpp>
16 #include <stan/math/prim/scal/fun/F32.hpp>
17 #include <stan/math/prim/scal/fun/falling_factorial.hpp>
18 #include <stan/math/prim/scal/fun/fdim.hpp>
19 #include <stan/math/prim/scal/fun/gamma_p.hpp>
20 #include <stan/math/prim/scal/fun/gamma_q.hpp>
21 #include <stan/math/prim/scal/fun/grad_2F1.hpp>
22 #include <stan/math/prim/scal/fun/grad_F32.hpp>
23 #include <stan/math/prim/scal/fun/grad_inc_beta.hpp>
24 #include <stan/math/prim/scal/fun/grad_reg_inc_beta.hpp>
25 #include <stan/math/prim/scal/fun/grad_reg_inc_gamma.hpp>
26 #include <stan/math/prim/scal/fun/ibeta.hpp>
27 #include <stan/math/prim/scal/fun/identity_constrain.hpp>
28 #include <stan/math/prim/scal/fun/identity_free.hpp>
29 #include <stan/math/prim/scal/fun/if_else.hpp>
30 #include <stan/math/prim/scal/fun/inc_beta.hpp>
31 #include <stan/math/prim/scal/fun/inc_beta_dda.hpp>
32 #include <stan/math/prim/scal/fun/inc_beta_ddb.hpp>
33 #include <stan/math/prim/scal/fun/inc_beta_ddz.hpp>
34 #include <stan/math/prim/scal/fun/int_step.hpp>
35 #include <stan/math/prim/scal/fun/inv.hpp>
36 #include <stan/math/prim/scal/fun/inv_cloglog.hpp>
37 #include <stan/math/prim/scal/fun/inv_logit.hpp>
38 #include <stan/math/prim/scal/fun/inv_sqrt.hpp>
39 #include <stan/math/prim/scal/fun/inv_square.hpp>
40 #include <stan/math/prim/scal/fun/inverse_softmax.hpp>
41 #include <stan/math/prim/scal/fun/is_inf.hpp>
42 #include <stan/math/prim/scal/fun/is_nan.hpp>
43 #include <stan/math/prim/scal/fun/is_uninitialized.hpp>
44 #include <stan/math/prim/scal/fun/lb_constrain.hpp>
45 #include <stan/math/prim/scal/fun/lb_free.hpp>
46 #include <stan/math/prim/scal/fun/lbeta.hpp>
47 #include <stan/math/prim/scal/fun/lgamma.hpp>
48 #include <stan/math/prim/scal/fun/lmgamma.hpp>
49 #include <stan/math/prim/scal/fun/log1m.hpp>
50 #include <stan/math/prim/scal/fun/log1m_exp.hpp>
51 #include <stan/math/prim/scal/fun/log1m_inv_logit.hpp>
52 #include <stan/math/prim/scal/fun/log1p.hpp>
53 #include <stan/math/prim/scal/fun/log1p_exp.hpp>
54 #include <stan/math/prim/scal/fun/log2.hpp>
55 #include <stan/math/prim/scal/fun/log_diff_exp.hpp>
56 #include <stan/math/prim/scal/fun/log_falling_factorial.hpp>
57 #include <stan/math/prim/scal/fun/log_inv_logit.hpp>
58 #include <stan/math/prim/scal/fun/log_mix.hpp>
59 #include <stan/math/prim/scal/fun/log_rising_factorial.hpp>
60 #include <stan/math/prim/scal/fun/log_sum_exp.hpp>
61 #include <stan/math/prim/scal/fun/logical_and.hpp>
62 #include <stan/math/prim/scal/fun/logical_eq.hpp>
63 #include <stan/math/prim/scal/fun/logical_gt.hpp>
64 #include <stan/math/prim/scal/fun/logical_gte.hpp>
65 #include <stan/math/prim/scal/fun/logical_lt.hpp>
66 #include <stan/math/prim/scal/fun/logical_lte.hpp>
67 #include <stan/math/prim/scal/fun/logical_negation.hpp>
68 #include <stan/math/prim/scal/fun/logical_neq.hpp>
69 #include <stan/math/prim/scal/fun/logical_or.hpp>
70 #include <stan/math/prim/scal/fun/logit.hpp>
71 #include <stan/math/prim/scal/fun/lub_constrain.hpp>
72 #include <stan/math/prim/scal/fun/lub_free.hpp>
73 #include <stan/math/prim/scal/fun/modified_bessel_first_kind.hpp>
74 #include <stan/math/prim/scal/fun/modified_bessel_second_kind.hpp>
75 #include <stan/math/prim/scal/fun/modulus.hpp>
76 #include <stan/math/prim/scal/fun/multiply_log.hpp>
77 #include <stan/math/prim/scal/fun/owens_t.hpp>
78 #include <stan/math/prim/scal/fun/Phi.hpp>
79 #include <stan/math/prim/scal/fun/Phi_approx.hpp>
80 #include <stan/math/prim/scal/fun/positive_constrain.hpp>
81 #include <stan/math/prim/scal/fun/positive_free.hpp>
82 #include <stan/math/prim/scal/fun/primitive_value.hpp>
83 #include <stan/math/prim/scal/fun/prob_constrain.hpp>
84 #include <stan/math/prim/scal/fun/prob_free.hpp>
85 #include <stan/math/prim/scal/fun/promote_scalar.hpp>
86 #include <stan/math/prim/scal/fun/promote_scalar_type.hpp>
87 #include <stan/math/prim/scal/fun/rising_factorial.hpp>
88 #include <stan/math/prim/scal/fun/sign.hpp>
89 #include <stan/math/prim/scal/fun/square.hpp>
90 #include <stan/math/prim/scal/fun/step.hpp>
91 #include <stan/math/prim/scal/fun/trigamma.hpp>
92 #include <stan/math/prim/scal/fun/ub_constrain.hpp>
93 #include <stan/math/prim/scal/fun/ub_free.hpp>
94 #include <stan/math/prim/scal/fun/value_of.hpp>
95 #include <stan/math/prim/scal/fun/value_of_rec.hpp>
96
97 #endif
ub_constrain.hpp
log_diff_exp.hpp
modulus.hpp
lgamma.hpp
falling_factorial.hpp
positive_free.hpp
inv_square.hpp
inverse_softmax.hpp
is_nan.hpp
inc_beta_ddz.hpp
Phi_approx.hpp
modified_bessel_second_kind.hpp
lb_free.hpp
digamma.hpp
rising_factorial.hpp
square.hpp
logical_and.hpp
is_inf.hpp
binary_log_loss.hpp
modified_bessel_first_kind.hpp
logical_negation.hpp
inv_cloglog.hpp
is_uninitialized.hpp
binomial_coefficient_log.hpp
bessel_first_kind.hpp
inc_beta_ddb.hpp
F32.hpp
gamma_q.hpp
logical_lte.hpp
abs.hpp
multiply_log.hpp
logical_neq.hpp
corr_constrain.hpp
log_inv_logit.hpp
log_sum_exp.hpp
prob_free.hpp
divide.hpp
logical_gt.hpp
logical_or.hpp
ibeta.hpp
log_rising_factorial.hpp
log1m_exp.hpp
log1m_inv_logit.hpp
log_mix.hpp
grad_2F1.hpp
primitive_value.hpp
identity_free.hpp
owens_t.hpp
logical_gte.hpp
promote_scalar_type.hpp
log1m.hpp
trigamma.hpp
value_of_rec.hpp
grad_inc_beta.hpp
logical_eq.hpp
prob_constrain.hpp
ub_free.hpp
gamma_p.hpp
grad_reg_inc_beta.hpp
log1p_exp.hpp
grad_F32.hpp
grad_reg_inc_gamma.hpp
constants.hpp
promote_scalar.hpp
lmgamma.hpp
int_step.hpp
sign.hpp
lbeta.hpp
identity_constrain.hpp
as_bool.hpp
log1p.hpp
inc_beta.hpp
if_else.hpp
bessel_second_kind.hpp
logical_lt.hpp
exp2.hpp
positive_constrain.hpp
value_of.hpp
logit.hpp
lub_constrain.hpp
step.hpp
inv_logit.hpp
log2.hpp
lub_free.hpp
Phi.hpp
log_falling_factorial.hpp
lb_constrain.hpp
inv.hpp
inv_sqrt.hpp
fdim.hpp
inc_beta_dda.hpp
corr_free.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.